// ========================================
// Pan and stone texture
// -----------------------------------------
// Made for Persistence of vision 3.6
//==========================================  
// Copyright 2006 Gilles Tran http://www.oyonale.com
// -----------------------------------------
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
// or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
// You are free:
// - to copy, distribute, display, and perform the work
// - to make derivative works
// - to make commercial use of the work
// Under the following conditions:
// - Attribution. You must give the original author credit.
// - For any reuse or distribution, you must make clear to others the license terms of this work.
// - Any of these conditions can be waived if you get permission from the copyright holder.
// Your fair use and other rights are in no way affected by the above. 
//==========================================  
#include "colors.inc"
#declare RadOK=2; // 0=no radiosity ; 1= low quality rad; 2= good quality
#declare ObjectOK=1; // turns object on
#declare PhotonsOK=1; // photons
#declare AreaOK=1; // area light
global_settings {
    max_trace_level 8
    //---------------------------------------
    // change gamma if necessary (scene too bright for instance)
    //---------------------------------------
    assumed_gamma 1
    //---------------------------------------
    noise_generator 1
    #if (RadOK>0)
        radiosity{
            #switch (RadOK)
                #case (1)
                    count 35 error_bound 1.8 
                #break
                #case (2)
                    count 100 error_bound 0.2
                #break
            #end    
            nearest_count 5 
            recursion_limit 1  
            low_error_factor 0.2 
            gray_threshold 0 
            minimum_reuse 0.015 
            brightness 1 
            adc_bailout 0.01/2      
            normal on
            media off
        }
    #end
    #if (PhotonsOK=1)
        photons {
            count 4000000                 // specify the density of photons
            autostop 0
            jitter .4
        }
    #end
}


#declare Camera=camera{
        location z*-40+y*40
        direction z*1.5
        up y
        right x*image_width/image_height
        look_at <0,4,0>
}
#declare Camera2=camera{ // test camera
      location z*-1000+y*1000
      direction z*1
      up y
      right x*image_width/image_height
      look_at <0,2,0>
}
camera{Camera}
//camera{Camera2}

#declare C_Sun= rgb <1,0.98,0.96>;

light_source{-z*10000,color C_Sun rotate x*30 rotate y*75
    photons {
    refraction off
    reflection on
    }
    #if (AreaOK=1)
        area_light 100*x,100*y,5,5 adaptive 1 jitter orient circular
    #end
}


sky_sphere{pigment{gradient y color_map{[0.5 White][0.6 rgb <92,126,202>/255]}}}


#declare T_Pan_Handle= texture{ // Handle
    pigment{rgb 0.1} 
    finish{ambient 0 diffuse 1 specular 0.5 roughness 0.07 reflection{0,0.2 fresnel on}} 
} 
#declare T_Pan_Interior = texture{
    pigment{White*0.9}
	finish{ambient 0 diffuse 1 specular 1 roughness 0.015 metallic brilliance 6 reflection{0,1 fresnel on metallic}}
}                                             

#declare T_Pan_Exterior = texture{
    // decoration created with Jaime Vives Piqueres' azulejos macro
    pigment{image_map{jpeg "decoration.jpg" map_type 2} scale <1,15,1> translate y*2}
	finish{ambient 0 diffuse 1 specular 1 roughness 0.03 metallic brilliance 4 reflection{0.2,1 fresnel on metallic}}
}


#if (ObjectOK=1)
    
    #include "pan.inc"
    #declare Pan=object{Pan scale 0.5 interior{ior 3}
        photons{
            target 1.0          // spacing multiplier for photons hitting the object
            refraction off
            reflection on
        }
    }
#else
    #declare Pan=cylinder{0,10*y,14 texture{T_Pan_Metal}  interior{ior 3}}
    
#end
// stone ground
#declare Ground=union{triangle{<-300,0,-300>,<300,0,-300>,<300,0,300>}triangle{<-300,0,-300>,<-300,0,300>,<300,0,300>}
    texture{
        pigment{
            image_map{jpeg "stone04.jpg"} 
        }

        normal{
            bump_map{jpeg "stone04.jpg"} 
            bump_size 5
        }

        finish{
            ambient 0 
            diffuse 1
        }
        rotate x*90
        scale 60
        
       
    }
}
//==========================================  
// All the objets
//==========================================  
union{
    object{Ground}
    object{Ground rotate x*-90}
    translate x*30+z*15
}
object{Pan rotate y*120 translate x*2}
              